pygeoip.util

Package pygeoip :: Module util |
[frames] | no frames]

# Module util

source code

Utility function for address translation

Authors:
  Jennifer Ennis <zaylea@gmail.com>, William Tisäter <william@defunct.cc>

License: Copyright(C) 2004 MaxMind LLC

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this program. If not, see <http://www.gnu.org/licenses/lgpl.txt>.

Functions
ip2long(ip) Wrapper function for IPv4 and IPv6 converters | source code

Variables
| __package__ = ``'``pygeoip``'``

Function Details

### ip2long(ip) | source code
Wrapper function for IPv4 and IPv6 converters Parameters: `ip` (str) - IPv4 or IPv6 address